@@ -24,17 +24,19 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt '
-           '-fno-semantic-interposition -march=armv6 -mfloat-abi=hard '
-           '-mfpu=vfp -O3 -pipe -fno-plt -march=armv6 -mfloat-abi=hard '
-           '-mfpu=vfp -O3 -pipe -fno-plt',
+           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+           '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
+           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+           '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
+           '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                     '-fno-plt -fno-semantic-interposition',
+                     '-fstack-protector-strong -fno-plt '
+                     '-fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -50,15 +52,15 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=armv6 "
-                '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt '
-                "-fno-semantic-interposition' "
+                '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fstack-protector-strong '
+                "-fno-plt -fno-semantic-interposition' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
                 "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.9.4/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.9.4/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.9.5/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.9.5/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -111,7 +113,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
@@ -566,6 +568,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
+ 'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
@@ -644,12 +647,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv6 -mfloat-abi=hard '
-                             '-mfpu=vfp -O3 -pipe -fno-plt '
-                             '-fno-semantic-interposition -march=armv6 '
-                             '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt '
+                             '-mfpu=vfp -O3 -pipe -fstack-protector-strong '
+                             '-fno-plt -fno-semantic-interposition '
                              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
-                             '-pipe -fno-plt -std=c99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-pipe -fstack-protector-strong -fno-plt '
+                             '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt -std=c99 '
+                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
@@ -657,10 +661,11 @@ build_time_vars = {'ABIFLAGS': '',
                              '-D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt '
-              '-fno-semantic-interposition -march=armv6 -mfloat-abi=hard '
-              '-mfpu=vfp -O3 -pipe -fno-plt -march=armv6 -mfloat-abi=hard '
-              '-mfpu=vfp -O3 -pipe -fno-plt',
+              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+              '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
+              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+              '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
+              '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
@@ -668,10 +673,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                   '-fno-plt -fno-semantic-interposition -march=armv6 '
-                   '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt -march=armv6 '
-                   '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt -std=c99 '
-                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-fstack-protector-strong -fno-plt '
+                   '-fno-semantic-interposition -march=armv6 -mfloat-abi=hard '
+                   '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt '
+                   '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
@@ -689,11 +696,14 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
-                        '-pipe -fno-plt -fno-semantic-interposition '
-                        '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                        '-fno-plt -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
-                        '-pipe -fno-plt -std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-pipe -fstack-protector-strong -fno-plt '
+                        '-fno-semantic-interposition -march=armv6 '
+                        '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt -march=armv6 '
+                        '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 '
@@ -706,7 +716,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.4',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.5',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -748,9 +758,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.4 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.5 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.4 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.5 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -773,8 +783,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.9.4',
- 'abs_srcdir': '/build/python/src/Python-3.9.4',
+ 'abs_builddir': '/build/python/src/Python-3.9.5',
+ 'abs_srcdir': '/build/python/src/Python-3.9.5',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
